@@ -7,7 +7,7 @@ import globus_sdk
 
 from globus_automate_client import flows_client
 from gladier.tests.test_data.gladier_mocks import mock_automate_flow_scope
-from gladier import GladierBaseClient, config
+from gladier import GladierBaseClient, config, version
 
 data_dir = os.path.join(os.path.dirname(__file__), 'test_data')
 
@@ -27,10 +27,25 @@ def two_step_flow():
         return json.loads(f.read())
 
 
+@pytest.fixture
+def mock_version_030(monkeypatch):
+    monkeypatch.setattr(version, '__version__', '0.3.0')
+    return version.__version__
+
+
+@pytest.fixture
+def mock_version_040(monkeypatch):
+    monkeypatch.setattr(version, '__version__', '0.4.0a1')
+    return version.__version__
+
+
 @pytest.fixture(autouse=True)
 def mock_config(monkeypatch):
-    monkeypatch.setattr(config.GladierConfig, 'save', Mock())
-    return config.GladierConfig
+    monkeypatch.setattr(config.GladierSecretsConfig, 'save', Mock())
+    monkeypatch.setattr(config.GladierSecretsConfig, 'read', Mock())
+    cfg = config.GladierSecretsConfig('mock_filename', 'section', 'client_id')
+    monkeypatch.setattr(GladierBaseClient, '_load_private_config', Mock(return_value=cfg))
+    return cfg
 
 
 @pytest.fixture(autouse=True)
@@ -78,6 +93,8 @@ def logged_in(monkeypatch):
     scopes = list(flows_client.ALL_FLOW_SCOPES) + [
         # Funcx Scope
         'https://auth.globus.org/scopes/facd7ccc-c5f4-42aa-916b-a0e270e2c2a9/all',
+        # Required by FuncX
+        'urn:globus:auth:scope:search.api.globus.org:all', 'openid',
         # The scope we got back from 'deploying' a flow with automate (of course, this is a mock)
         mock_automate_flow_scope,
     ]
@@ -101,6 +118,26 @@ def globus_response():
 @pytest.fixture
 def mock_globus_api_error(monkeypatch):
     class MockGlobusAPIError(Exception):
-        pass
-    monkeypatch.setattr(globus_sdk, 'GlobusAPIError', MockGlobusAPIError)
-    return globus_sdk.GlobusAPIError
+        http_status = 400
+        code = 'Error'
+        message = json.dumps(
+            {'error': {
+                'code': 'FLOW_GENERIC_ERROR',
+                'detail': 'Something terrible happened, and its your fault.'
+                }
+             })
+    monkeypatch.setattr(globus_sdk.exc, 'GlobusAPIError', MockGlobusAPIError)
+    return globus_sdk.exc.GlobusAPIError
+
+
+@pytest.fixture
+def mock_dependent_token_change_error(mock_globus_api_error):
+    # Yes, this is a real Globus automate exception message...
+    automate_message = json.dumps(
+        {'error': {'code': 'FLOW_INPUT_ERROR',
+                   'detail': 'For RunAs value User, unable to get tokens for scopes '
+                   "{'https://auth.globus.org/scopes/actions.globus.org/transfer/transfer'}"
+                   }
+         })
+    mock_globus_api_error.message = automate_message
+    return mock_globus_api_error
